==> zio-aws-redshiftdata_3-5.17.257.1-sources.jar: zio/aws/redshiftdata/model/BatchExecuteStatementRequest.scala <==
package zio.aws.redshiftdata.model
import zio.ZIO
import zio.aws.redshiftdata.model.primitives.{
  SecretArn,
  StatementString,
  WorkgroupNameString,
  StatementNameString,
  Location
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class BatchExecuteStatementRequest(
    clusterIdentifier: Optional[Location] = Optional.Absent,
    database: String,
    dbUser: Optional[String] = Optional.Absent,
    secretArn: Optional[SecretArn] = Optional.Absent,
    sqls: Iterable[StatementString],
    statementName: Optional[StatementNameString] = Optional.Absent,
    withEvent: Optional[Boolean] = Optional.Absent,
    workgroupName: Optional[WorkgroupNameString] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshiftdata.model.BatchExecuteStatementRequest = {
    import BatchExecuteStatementRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshiftdata.model.BatchExecuteStatementRequest
      .builder()
      .optionallyWith(
        clusterIdentifier.map(value => Location.unwrap(value): java.lang.String)
      )(_.clusterIdentifier)
      .database(database: java.lang.String)
      .optionallyWith(dbUser.map(value => value: java.lang.String))(_.dbUser)
      .optionallyWith(
        secretArn.map(value => SecretArn.unwrap(value): java.lang.String)
      )(_.secretArn)
      .sqls(sqls.map { item =>
        StatementString.unwrap(item): java.lang.String
      }.asJavaCollection)
      .optionallyWith(
        statementName.map(value =>
          StatementNameString.unwrap(value): java.lang.String
        )
      )(_.statementName)
      .optionallyWith(withEvent.map(value => value: java.lang.Boolean))(
        _.withEvent
      )
      .optionallyWith(
        workgroupName.map(value =>
          WorkgroupNameString.unwrap(value): java.lang.String
        )
      )(_.workgroupName)
      .build()
  }
  def asReadOnly
      : zio.aws.redshiftdata.model.BatchExecuteStatementRequest.ReadOnly =
    zio.aws.redshiftdata.model.BatchExecuteStatementRequest
      .wrap(buildAwsValue())
}
object BatchExecuteStatementRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshiftdata.model.BatchExecuteStatementRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshiftdata.model.BatchExecuteStatementRequest =
      zio.aws.redshiftdata.model.BatchExecuteStatementRequest(
        clusterIdentifier.map(value => value),
        database,
        dbUser.map(value => value),
        secretArn.map(value => value),
        sqls,
        statementName.map(value => value),
        withEvent.map(value => value),
        workgroupName.map(value => value)
      )
    def clusterIdentifier: Optional[Location]
    def database: String
    def dbUser: Optional[String]
    def secretArn: Optional[SecretArn]
    def sqls: List[StatementString]
    def statementName: Optional[StatementNameString]
    def withEvent: Optional[Boolean]
    def workgroupName: Optional[WorkgroupNameString]
    def getClusterIdentifier: ZIO[Any, AwsError, Location] =
      AwsError.unwrapOptionField("clusterIdentifier", clusterIdentifier)
    def getDatabase: ZIO[Any, Nothing, String] = ZIO.succeed(database)
    def getDbUser: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("dbUser", dbUser)
    def getSecretArn: ZIO[Any, AwsError, SecretArn] =
      AwsError.unwrapOptionField("secretArn", secretArn)
    def getSqls: ZIO[Any, Nothing, List[StatementString]] = ZIO.succeed(sqls)
    def getStatementName: ZIO[Any, AwsError, StatementNameString] =
      AwsError.unwrapOptionField("statementName", statementName)
    def getWithEvent: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("withEvent", withEvent)
    def getWorkgroupName: ZIO[Any, AwsError, WorkgroupNameString] =
      AwsError.unwrapOptionField("workgroupName", workgroupName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshiftdata.model.BatchExecuteStatementRequest
  ) extends zio.aws.redshiftdata.model.BatchExecuteStatementRequest.ReadOnly {
    override val clusterIdentifier: Optional[Location] = zio.aws.core.internal
      .optionalFromNullable(impl.clusterIdentifier())
      .map(value => zio.aws.redshiftdata.model.primitives.Location(value))
    override val database: String = impl.database(): String
    override val dbUser: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.dbUser())
      .map(value => value: String)
    override val secretArn: Optional[SecretArn] = zio.aws.core.internal
      .optionalFromNullable(impl.secretArn())
      .map(value => zio.aws.redshiftdata.model.primitives.SecretArn(value))
    override val sqls: List[StatementString] = impl
      .sqls()
      .asScala
      .map { item =>
        zio.aws.redshiftdata.model.primitives.StatementString(item)
      }
      .toList
    override val statementName: Optional[StatementNameString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.statementName())
        .map(value =>
          zio.aws.redshiftdata.model.primitives.StatementNameString(value)
        )
    override val withEvent: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.withEvent())
      .map(value => value: Boolean)
    override val workgroupName: Optional[WorkgroupNameString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.workgroupName())
        .map(value =>
          zio.aws.redshiftdata.model.primitives.WorkgroupNameString(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshiftdata.model.BatchExecuteStatementRequest
  ): zio.aws.redshiftdata.model.BatchExecuteStatementRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-redshiftdata_3-6.20.115.1-sources.jar: zio/aws/redshiftdata/model/BatchExecuteStatementRequest.scala <==
package zio.aws.redshiftdata.model
import zio.ZIO
import zio.aws.redshiftdata.model.primitives.{
  SecretArn,
  StatementString,
  WorkgroupNameString,
  ClientToken,
  StatementNameString,
  Location
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class BatchExecuteStatementRequest(
    clientToken: Optional[ClientToken] = Optional.Absent,
    clusterIdentifier: Optional[Location] = Optional.Absent,
    database: String,
    dbUser: Optional[String] = Optional.Absent,
    secretArn: Optional[SecretArn] = Optional.Absent,
    sqls: Iterable[StatementString],
    statementName: Optional[StatementNameString] = Optional.Absent,
    withEvent: Optional[Boolean] = Optional.Absent,
    workgroupName: Optional[WorkgroupNameString] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshiftdata.model.BatchExecuteStatementRequest = {
    import BatchExecuteStatementRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshiftdata.model.BatchExecuteStatementRequest
      .builder()
      .optionallyWith(
        clientToken.map(value => ClientToken.unwrap(value): java.lang.String)
      )(_.clientToken)
      .optionallyWith(
        clusterIdentifier.map(value => Location.unwrap(value): java.lang.String)
      )(_.clusterIdentifier)
      .database(database: java.lang.String)
      .optionallyWith(dbUser.map(value => value: java.lang.String))(_.dbUser)
      .optionallyWith(
        secretArn.map(value => SecretArn.unwrap(value): java.lang.String)
      )(_.secretArn)
      .sqls(sqls.map { item =>
        StatementString.unwrap(item): java.lang.String
      }.asJavaCollection)
      .optionallyWith(
        statementName.map(value =>
          StatementNameString.unwrap(value): java.lang.String
        )
      )(_.statementName)
      .optionallyWith(withEvent.map(value => value: java.lang.Boolean))(
        _.withEvent
      )
      .optionallyWith(
        workgroupName.map(value =>
          WorkgroupNameString.unwrap(value): java.lang.String
        )
      )(_.workgroupName)
      .build()
  }
  def asReadOnly
      : zio.aws.redshiftdata.model.BatchExecuteStatementRequest.ReadOnly =
    zio.aws.redshiftdata.model.BatchExecuteStatementRequest
      .wrap(buildAwsValue())
}
object BatchExecuteStatementRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshiftdata.model.BatchExecuteStatementRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshiftdata.model.BatchExecuteStatementRequest =
      zio.aws.redshiftdata.model.BatchExecuteStatementRequest(
        clientToken.map(value => value),
        clusterIdentifier.map(value => value),
        database,
        dbUser.map(value => value),
        secretArn.map(value => value),
        sqls,
        statementName.map(value => value),
        withEvent.map(value => value),
        workgroupName.map(value => value)
      )
    def clientToken: Optional[ClientToken]
    def clusterIdentifier: Optional[Location]
    def database: String
    def dbUser: Optional[String]
    def secretArn: Optional[SecretArn]
    def sqls: List[StatementString]
    def statementName: Optional[StatementNameString]
    def withEvent: Optional[Boolean]
    def workgroupName: Optional[WorkgroupNameString]
    def getClientToken: ZIO[Any, AwsError, ClientToken] =
      AwsError.unwrapOptionField("clientToken", clientToken)
    def getClusterIdentifier: ZIO[Any, AwsError, Location] =
      AwsError.unwrapOptionField("clusterIdentifier", clusterIdentifier)
    def getDatabase: ZIO[Any, Nothing, String] = ZIO.succeed(database)
    def getDbUser: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("dbUser", dbUser)
    def getSecretArn: ZIO[Any, AwsError, SecretArn] =
      AwsError.unwrapOptionField("secretArn", secretArn)
    def getSqls: ZIO[Any, Nothing, List[StatementString]] = ZIO.succeed(sqls)
    def getStatementName: ZIO[Any, AwsError, StatementNameString] =
      AwsError.unwrapOptionField("statementName", statementName)
    def getWithEvent: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("withEvent", withEvent)
    def getWorkgroupName: ZIO[Any, AwsError, WorkgroupNameString] =
      AwsError.unwrapOptionField("workgroupName", workgroupName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshiftdata.model.BatchExecuteStatementRequest
  ) extends zio.aws.redshiftdata.model.BatchExecuteStatementRequest.ReadOnly {
    override val clientToken: Optional[ClientToken] = zio.aws.core.internal
      .optionalFromNullable(impl.clientToken())
      .map(value => zio.aws.redshiftdata.model.primitives.ClientToken(value))
    override val clusterIdentifier: Optional[Location] = zio.aws.core.internal
      .optionalFromNullable(impl.clusterIdentifier())
      .map(value => zio.aws.redshiftdata.model.primitives.Location(value))
    override val database: String = impl.database(): String
    override val dbUser: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.dbUser())
      .map(value => value: String)
    override val secretArn: Optional[SecretArn] = zio.aws.core.internal
      .optionalFromNullable(impl.secretArn())
      .map(value => zio.aws.redshiftdata.model.primitives.SecretArn(value))
    override val sqls: List[StatementString] = impl
      .sqls()
      .asScala
      .map { item =>
        zio.aws.redshiftdata.model.primitives.StatementString(item)
      }
      .toList
    override val statementName: Optional[StatementNameString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.statementName())
        .map(value =>
          zio.aws.redshiftdata.model.primitives.StatementNameString(value)
        )
    override val withEvent: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.withEvent())
      .map(value => value: Boolean)
    override val workgroupName: Optional[WorkgroupNameString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.workgroupName())
        .map(value =>
          zio.aws.redshiftdata.model.primitives.WorkgroupNameString(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshiftdata.model.BatchExecuteStatementRequest
  ): zio.aws.redshiftdata.model.BatchExecuteStatementRequest.ReadOnly =
    new Wrapper(impl)
}
